@@ -20,10 +20,13 @@
  
 #include "dialog_glom.h"
 
-Dialog_Glom::Dialog_Glom(Box_DB* pBox)
+namespace Glom
 {
-  set_border_width(6);
- 
+
+Dialog_Glom::Dialog_Glom(Box_WithButtons* pBox)
+{
+  set_border_width(Utils::DEFAULT_SPACING_SMALL);
+
   m_pBox = pBox;
 
   if(m_pBox)
@@ -48,3 +51,5 @@ void Dialog_Glom::on_box_cancelled()
 {
   hide();
 }
+
+} //namespace Glom
